@@ -1,24 +1,9 @@
 /*
- * This file is part of the KDE Baloo Project
- * Copyright (C) 2013  Vishesh Handa <me@vhanda.in>
- *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) version 3, or any
- * later version accepted by the membership of KDE e.V. (or its
- * successor approved by the membership of KDE e.V.), which shall
- * act as a proxy defined in Section 6 of version 3 of the license.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- *
- */
+    This file is part of the KDE Baloo Project
+    SPDX-FileCopyrightText: 2013 Vishesh Handa <me@vhanda.in>
+
+    SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
+*/
 
 #include "query.h"
 #include "term.h"
@@ -29,7 +14,6 @@
 #include <QString>
 #include <QStringList>
 #include <QSharedPointer>
-#include <QList>
 #include <QUrlQuery>
 
 #include <QJsonDocument>
@@ -313,14 +297,48 @@ QUrl Query::toSearchUrl(const QString& title)
     return url;
 }
 
+static QString jsonQueryFromUrl(const QUrl &url)
+{
+    const QString path = url.path();
+
+    if (path == QLatin1String("/documents")) {
+        return QStringLiteral("{\"type\":[\"Document\"]}");
+    } else if (path.endsWith(QLatin1String("/images"))) {
+        return QStringLiteral("{\"type\":[\"Image\"]}");
+    } else if (path.endsWith(QLatin1String("/audio"))) {
+        return QStringLiteral("{\"type\":[\"Audio\"]}");
+    } else if (path.endsWith(QLatin1String("/videos"))) {
+        return QStringLiteral("{\"type\":[\"Video\"]}");
+    }
+
+    return QString();
+}
+
 Query Query::fromSearchUrl(const QUrl& url)
 {
     if (url.scheme() != QLatin1String("baloosearch"))
         return Query();
 
     QUrlQuery urlQuery(url);
-    QString jsonString = urlQuery.queryItemValue(QStringLiteral("json"), QUrl::FullyDecoded);
-    return Query::fromJSON(jsonString.toUtf8());
+
+    if (urlQuery.hasQueryItem(QStringLiteral("json"))) {
+        QString jsonString = urlQuery.queryItemValue(QStringLiteral("json"), QUrl::FullyDecoded);
+        return Query::fromJSON(jsonString.toUtf8());
+    }
+
+    if (urlQuery.hasQueryItem(QStringLiteral("query"))) {
+        QString queryString = urlQuery.queryItemValue(QStringLiteral("query"), QUrl::FullyDecoded);
+        Query q;
+        q.setSearchString(queryString);
+        return q;
+    }
+
+    const QString jsonString = jsonQueryFromUrl(url);
+    if (!jsonString.isEmpty()) {
+        return Query::fromJSON(jsonString.toUtf8());
+    }
+
+    return Query();
 }
 
 QString Query::titleFromQueryUrl(const QUrl& url)
